:py:mod:`byma`
==============

.. py:module:: byma

.. autoapi-nested-parse::

   ByMa: A scientific computing package for Python
   ================================================

   Documentation is available in the docstrings and
   online at 

   Subpackages
   -----------
   Using any of these subpackages requires an explicit import. For example,
   ``import byma.nuby``.

   ::

    nuby                         --- Numerical Bifurcation Analysis Tools
    iteral                       --- Tools for iterative algorithms
    pyplot                       --- Tools for plotting functions
    interface                    --- Interface functions



Subpackages
-----------
.. toctree::
   :titlesonly:
   :maxdepth: 3

   interface/index.rst
   iteral/index.rst
   nuby/index.rst
   numy/index.rst
   pyplot/index.rst


